==> haskell-hslua-module-path-1.1.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-path
version:              1.1.0
visibility:           public
id:                   hslua-module-path-1.1.0-GSMdh7VwC7tETWJV2lQlPi
key:                  hslua-module-path-1.1.0-GSMdh7VwC7tETWJV2lQlPi
license:              MIT
copyright:            © 2020-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  10388efea7cf0a54bf0dc10b428faf20
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.0-GSMdh7VwC7tETWJV2lQlPi
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-LpCrvVg83tO6brKlXPQhdj
    hslua-marshalling-2.3.1-ClftDKSXsq1GzeFqthAmw4
    hslua-packaging-2.3.1-3B4ICaBiMxVGtohbyaesGZ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-module-path
version:              1.1.0
visibility:           public
id:                   hslua-module-path-1.1.0-7BBRfOrkxv8jKP2hI3kdK
key:                  hslua-module-path-1.1.0-7BBRfOrkxv8jKP2hI3kdK
license:              MIT
copyright:            © 2020-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  fafdcfac4f3d4a00839ec78c8dd9039f
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-module-path-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.0-7BBRfOrkxv8jKP2hI3kdK
depends:
    base-4.16.4.0 filepath-1.4.2.2
    hslua-core-2.3.1-AqcWVQ7xHOm3kWrtK50zzZ
    hslua-marshalling-2.3.1-BRBIifQ0p8sHNRJh5r2GI2
    hslua-packaging-2.3.1-EbbUiOlzXl0Gjk7opZDIfX text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
